==> json_response-2.0.0.tar.gz: test/src/json_array_impl_test.dart <==
// Copyright (c) 2021, Kato Shinya. All rights reserved.
// Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.

// Package imports:
import 'package:test/test.dart';

// Project imports:
import 'package:json_response/src/json_array_impl.dart';

void main() {
  test('Test when JSON array is empty.', () {
    final jsonArray = JsonArrayImpl.fromList(values: []);
    expect(jsonArray.isEmpty, true);
    expect(jsonArray.isNotEmpty, false);
  });

  test('Test when JSON array is not empty', () {
    final jsonArray = JsonArrayImpl.fromList(
      values: [
        {'key1': 'value1', 'key2': 'value2'},
        {'key1': 'value1', 'key2': 'value2'},
        {'key1': 'value1', 'key2': 'value2'},
      ],
    );

    expect(jsonArray.isEmpty, false);
    expect(jsonArray.isNotEmpty, true);

    jsonArray.forEach((json) {
      expect(json.isNotEmpty, true);
      expect(json.getString(key: 'key1'), 'value1');
      expect(json.getString(key: 'key2'), 'value2');
    });

    int testIndex = 0;
    jsonArray.enumerate((index, json) {
      expect(json.isNotEmpty, true);
      expect(json.getString(key: 'key1'), 'value1');
      expect(json.getString(key: 'key2'), 'value2');
      expect(index, testIndex);
      testIndex++;
    });

    expect(jsonArray.get(index: 1).getString(key: 'key2'), 'value2');
  });

  test('Test when JSON array is nested.', () {
    final jsonArray = JsonArrayImpl.fromList(
      values: [
        [
          {'key1': 'value1', 'key2': 'value2'}
        ],
        [
          {'key1': 'value1', 'key2': 'value2'}
        ],
        [
          {'key1': 'value1', 'key2': 'value2'}
        ],
      ],
    );

    expect(jsonArray.isEmpty, false);
    expect(jsonArray.isNotEmpty, true);

    jsonArray.forEachArray((jsonArray) {
      expect(jsonArray.isNotEmpty, true);

      jsonArray.forEach((json) {
        expect(json.getString(key: 'key1'), 'value1');
        expect(json.getString(key: 'key2'), 'value2');
      });
    });

    int testIndex = 0;
    jsonArray.enumeratArray((index, jsonArray) {
      expect(jsonArray.isNotEmpty, true);

      jsonArray.forEach((json) {
        expect(json.getString(key: 'key1'), 'value1');
        expect(json.getString(key: 'key2'), 'value2');
      });

      expect(index, testIndex);
      testIndex++;
    });

    expect(jsonArray.getArray(index: 1).get(index: 0).getString(key: 'key2'),
        'value2');
    expect(jsonArray.toFlat().toString(),
        '[{key1: value1, key2: value2}, {key1: value1, key2: value2}, {key1: value1, key2: value2}]');
  });
}

==> json_response-2.3.0.tar.gz: test/src/json_array_impl_test.dart <==
// Copyright (c) 2021, Kato Shinya. All rights reserved.
// Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.

// Package imports:
import 'package:test/test.dart';

// Project imports:
import 'package:json_response/src/json_array_impl.dart';

void main() {
  test('Test when JSON array is empty.', () {
    final jsonArray = JsonArrayImpl.fromList(values: []);
    expect(jsonArray.isEmpty, true);
    expect(jsonArray.isNotEmpty, false);
  });

  test('Test when JSON array is not empty', () {
    final jsonArray = JsonArrayImpl.fromList(
      values: [
        {'key1': 'value1', 'key2': 'value2'},
        {'key1': 'value1', 'key2': 'value2'},
        {'key1': 'value1', 'key2': 'value2'},
      ],
    );

    expect(jsonArray.isEmpty, false);
    expect(jsonArray.isNotEmpty, true);

    jsonArray.forEach((json) {
      expect(json.isNotEmpty, true);
      expect(json.getString(key: 'key1'), 'value1');
      expect(json.getString(key: 'key2'), 'value2');
    });

    int testIndex = 0;
    jsonArray.enumerate((index, json) {
      expect(json.isNotEmpty, true);
      expect(json.getString(key: 'key1'), 'value1');
      expect(json.getString(key: 'key2'), 'value2');
      expect(index, testIndex);
      testIndex++;
    });

    expect(jsonArray.get(index: 1).getString(key: 'key2'), 'value2');
  });

  test('Test when JSON array is nested.', () {
    final jsonArray = JsonArrayImpl.fromList(
      values: [
        [
          {'key1': 'value1', 'key2': 'value2'}
        ],
        [
          {'key1': 'value1', 'key2': 'value2'}
        ],
        [
          {'key1': 'value1', 'key2': 'value2'}
        ],
      ],
    );

    expect(jsonArray.isEmpty, false);
    expect(jsonArray.isNotEmpty, true);

    jsonArray.forEachArray((jsonArray) {
      expect(jsonArray.isNotEmpty, true);

      jsonArray.forEach((json) {
        expect(json.getString(key: 'key1'), 'value1');
        expect(json.getString(key: 'key2'), 'value2');
      });
    });

    int testIndex = 0;
    jsonArray.enumerateArray((index, jsonArray) {
      expect(jsonArray.isNotEmpty, true);

      jsonArray.forEach((json) {
        expect(json.getString(key: 'key1'), 'value1');
        expect(json.getString(key: 'key2'), 'value2');
      });

      expect(index, testIndex);
      testIndex++;
    });

    expect(jsonArray.getArray(index: 1).get(index: 0).getString(key: 'key2'),
        'value2');
    expect(jsonArray.flatten().toString(),
        '[{key1: value1, key2: value2}, {key1: value1, key2: value2}, {key1: value1, key2: value2}]');
  });
}
